@@ -46,9 +46,6 @@ def GetBytes(dev,HV_Ref,DAC_Ref,T_Ref,MaxNumBit=1000000,TC=True):
         BitRead=BitRead+len(Bytes)*8
         BytesReturn+=Bytes
 
-    BytesReturn_Pre=BytesReturn[0]
-    BytesReturn=BytesReturn_Pre[0:MaxNumBit]
-
     return BytesReturn
 
 
